@@ -9,7 +9,7 @@
  * License version 1.0.
  *
  ************************************************************)
-(* $Id: pa_pragma.ml,v 1.4 2003/11/22 21:54:29 oiwa Exp $ *)
+(* $Id: pa_pragma.ml 118 2005-01-23 12:04:31Z yutaka $ *)
 
 (* provides camlp4 "pragma": allow specifying user-defined camlp4 *)
 (* option in program: *)
@@ -20,6 +20,10 @@ open Pcaml
 #load "pa_extend.cmo";;
 #load "q_MLast.cmo";;
 
+#if 3.06 | 3.07pre | 3.07 | 3.07_5 | 3.07_19
+#define _loc loc
+#endif
+
 let rec find_action s = function
     [] -> raise Not_found
   | (n,a,_)::tl -> if n = s then a else find_action s tl
@@ -51,33 +55,33 @@ let _ = EXTEND
     implem: FIRST
     [ [
       "#"; LIDENT "pragma" ; name = [ n = LIDENT -> n | n = STRING -> n ];
-	arg = OPT [ "="; e = expr LEVEL "simple" -> e, loc]; ";;" ->
+	arg = OPT [ "="; e = expr LEVEL "simple" -> e, _loc]; ";;" ->
 	  (* (sil, stopped) = SELF -> *)
-	  do_pragma name arg loc;
-	  ([ <:str_item< declare end >>, loc ], true)
+	  do_pragma name arg _loc;
+	  ([ <:str_item< declare end >>, _loc ], true)
     ] ];
     interf: FIRST
     [ [
       "#"; LIDENT "pragma" ; name = [ n = LIDENT -> n | n = STRING -> n ];
-	arg = OPT [ "="; e = expr LEVEL "simple" -> e, loc]; ";;" ->
+	arg = OPT [ "="; e = expr LEVEL "simple" -> e, _loc]; ";;" ->
 	  (* (sil, stopped) = SELF -> *)
-	  do_pragma name arg loc;
-	  ([ <:sig_item< declare end >>, loc ], true)
+	  do_pragma name arg _loc;
+	  ([ <:sig_item< declare end >>, _loc ], true)
     ] ];
   use_file: FIRST
     [ [
       "#"; LIDENT "pragma" ; name = [ n = LIDENT -> n | n = STRING -> n ];
-      arg = OPT [ "="; e = expr LEVEL "simple" -> e, loc]; ";;" ->
+      arg = OPT [ "="; e = expr LEVEL "simple" -> e, _loc]; ";;" ->
 	  (* (sil, stopped) = SELF -> *)
-	do_pragma name arg loc;
+	do_pragma name arg _loc;
 	([ <:str_item< declare end >> ], true)
     ] ];
   top_phrase: FIRST
     [ [
       "#"; LIDENT "pragma" ; name = [ n = LIDENT -> n | n = STRING -> n ];
-	arg = OPT [ "="; e = expr LEVEL "simple" -> e, loc]; ";;" ->
+	arg = OPT [ "="; e = expr LEVEL "simple" -> e, _loc]; ";;" ->
 	  (* (sil, stopped) = SELF -> *)
-	  do_pragma name arg loc;
+	  do_pragma name arg _loc;
 	  Some <:str_item< declare end >>
     ] ];
   END
